
Introspection
=============

This module is a collection of new or improved introspection functions.
Some functions are improved versions of the functions found in the :mod:`inspect` module, others are completely new.

The available functions have been roughly categorized by what they return or what kind of objects they operate on.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   function_signatures.rst
   call_stack.rst
   classes.rst
   dundermethods.rst
   typing.rst
   misc.rst
